#include "chil_global.h"

int
CHILPrintFileInformation(ChilboltonFile * chilfile)
{

  CHILPrintf("File %s:\n",chilfile->name);
  CHILPrintf("   Position: ");
  switch (chilfile->position) {
  case FILE_CLOSED:
    CHILPrintf("file closed\n");
    break;
  case START_OF_IR:
    CHILPrintf("start of information record\n");
    break;
  case START_OF_DATA:
    CHILPrintf("start of data\n");
    break;
  case START_OF_RAY:
    CHILPrintf("start of ray\n");
    break;
  case START_OF_FILE:
    CHILPrintf("start of file\n");
    break;
  default:
    CHILPrintf("unknown\n");
  }
  if (chilfile->is_raw) {
    CHILPrintf("   File is raw\n");
  } 
  else {
    if (chilfile->summary_exists) {
      CHILPrintf("   Number of rasters: %hu\n",chilfile->nrasters);
      /*
	CHILPrintf("   Raster numbers:");
	for (i=0;i<chilfile->nrasters;i++) {
	CHILPrintf(" %hu",chilfile->raster[i]);
	};
      */
    }
    else
      CHILPrintf("   No summary file found\n");
    CHILPrintf("   Current raster index (0 based): %hu\n",chilfile->iraster);

  }
  CHILPrintf("   Current scan index (0 based):   %hu\n",chilfile->iscan);
  return CHIL_OK;
}

int
CHILPrintRasterInformation(RasterInfo * info)
{
  char system[10];

  CHILPrintf("Raster %hd:\n",info->raster);
  CHILSystemName(info,system);
  CHILPrintf("   System: %s (ID %hu)\n",system,info->system_id);
  CHILPrintf("   Frequency: %g GHz\n",info->frequency);
  CHILPrintf("   Date: %hu/%hu/%hu\n",info->day,info->month,info->year);
  CHILPrintf("   Start time: %02hu:%02hu:%02hu\n",info->hour,info->minute,info->second);
  if (info->cloud_data)
    CHILPrintf("   Cloud data\n");
  else {
    char *scan_type = "unknown";
    switch(info->sweep_mode) {
    case UF_RHI: scan_type = "RHI"; break;
    case UF_PPI: scan_type = "PPI"; break;
    case UF_COPLANE: scan_type = "slant plane"; break;
    case UF_DWELL: scan_type = "fixed"; break;
    case UF_CAL: scan_type = "calibration"; break;
    case UF_MANUAL: scan_type = "manual"; break;   
    }
    CHILPrintf("   Scan type: %s\n", scan_type);
  }
  CHILPrintf("   Number of scans: %hu\n",info->nscans);
  CHILPrintf("   Number of fields: %hu\n",info->nrawfields);
  CHILPrintf("   Time stamping on? %hu\n",info->time_stamping);
  CHILPrintf("   Minimum gate: %hu\n",info->min_gate);
  CHILPrintf("   Maximum gate: %hu\n",info->max_gate);
  CHILPrintf("   Gate spacing: %hd m\n",info->gate_spacing);
  if (info->range_offset != 0)
    CHILPrintf("   Range offset: %hd m\n",info->range_offset);
  return CHIL_OK;
}

int
CHILPrintFieldInformation(Ray * ray)
{
  char fielddesc[64];
  int desclen,i;

  CHILPrintf("Data acquisition setup:\n");
  CHILPrintf("   Averaging %hu gates\n",ray->avegates);
  CHILPrintf("   Averaging %hu rays\n",ray->averays);
  CHILPrintf("   %d fields:\n", ray->ntotal);
  for (i=0;i< ray->ntotal;i++) {
    desclen=strlen(CHILFieldName(ray,i,fielddesc));
    strcpy(fielddesc+desclen,", ");
    desclen=desclen+2+strlen(CHILFieldDescription(ray,i,fielddesc+desclen+2));
    strcpy(fielddesc+desclen," (");
    desclen=desclen+2+strlen(CHILFieldUnits(ray,i,fielddesc+desclen+2));
    strcpy(fielddesc+desclen,")");
    CHILPrintf("      %s\n",fielddesc);
  }
  return CHIL_OK;
}

int
CHILPrintRayInformation(Ray * ray)
{
  CHILPrintf("Ray %hu:\n",ray->index);
  CHILPrintf("   Number of gates: %hu\n",ray->ngates);
  CHILPrintf("   Number of fields: %hu\n",ray->nrawfields);
  CHILPrintf("   Decimal hours: %f UTC\n",ray->utc);
  CHILPrintf("   Elevation: %g\n",ray->elevation);
  CHILPrintf("   Azimuth: %g\n",ray->azimuth);
  CHILPrintf("   First range gate: %g km (uncorrected)\n",ray->range[0]);
  return CHIL_OK;
}

int
CHILPrintInformationRecord(RasterInfo *info)
{
  int x = 0, y = 0;
  CHILPrintf("Raw information record (64 bytes):");
  for (y = 0; y < 4; ++y) {
    CHILPrintf("\n%02d:", y * 16);
    for (x = 0; x < 16; ++x) {
      CHILPrintf("%4hhu", info->raw[y * 16 + x]);
    }
  }
  return CHIL_OK;
}
